import * as ec2 from '@aws-cdk/aws-ec2';
import * as iam from '@aws-cdk/aws-iam';
import * as sfn from '@aws-cdk/aws-stepfunctions';
import { AlgorithmSpecification, Channel, OutputDataConfig, ResourceConfig, StoppingCondition, VpcConfig } from './sagemaker-task-base-types';
/**
 *  @experimental
 */
export interface SagemakerTrainTaskProps {
    /**
     * Training Job Name.
     */
    readonly trainingJobName: string;
    /**
     * Role for the Training Job. The role must be granted all necessary permissions for the SageMaker training job to
     * be able to operate.
     *
     * See https://docs.aws.amazon.com/fr_fr/sagemaker/latest/dg/sagemaker-roles.html#sagemaker-roles-createtrainingjob-perms
     *
     * @default - a role with appropriate permissions will be created.
     */
    readonly role?: iam.IRole;
    /**
     * The service integration pattern indicates different ways to call SageMaker APIs.
     *
     * The valid value is either FIRE_AND_FORGET or SYNC.
     *
     * @default FIRE_AND_FORGET
     */
    readonly integrationPattern?: sfn.ServiceIntegrationPattern;
    /**
     * Identifies the training algorithm to use.
     */
    readonly algorithmSpecification: AlgorithmSpecification;
    /**
     * Hyperparameters to be used for the train job.
     */
    readonly hyperparameters?: {
        [key: string]: any;
    };
    /**
     *  Describes the various datasets (e.g. train, validation, test) and the Amazon S3 location where stored.
     */
    readonly inputDataConfig: Channel[];
    /**
     * Tags to be applied to the train job.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Identifies the Amazon S3 location where you want Amazon SageMaker to save the results of model training.
     */
    readonly outputDataConfig: OutputDataConfig;
    /**
     * Identifies the resources, ML compute instances, and ML storage volumes to deploy for model training.
     */
    readonly resourceConfig?: ResourceConfig;
    /**
     * Sets a time limit for training.
     */
    readonly stoppingCondition?: StoppingCondition;
    /**
     * Specifies the VPC that you want your training job to connect to.
     */
    readonly vpcConfig?: VpcConfig;
}
/**
 * Class representing the SageMaker Create Training Job task.
 *
 * @experimental
 */
export declare class SagemakerTrainTask implements iam.IGrantable, ec2.IConnectable, sfn.IStepFunctionsTask {
    private readonly props;
    /**
     * Allows specify security group connections for instances of this fleet.
     */
    readonly connections: ec2.Connections;
    /**
     * The Algorithm Specification
     */
    private readonly algorithmSpecification;
    /**
     * The Input Data Config.
     */
    private readonly inputDataConfig;
    /**
     * The resource config for the task.
     */
    private readonly resourceConfig;
    /**
     * The resource config for the task.
     */
    private readonly stoppingCondition;
    private readonly vpc?;
    private securityGroup?;
    private readonly securityGroups;
    private readonly subnets?;
    private readonly integrationPattern;
    private _role?;
    private _grantPrincipal?;
    constructor(props: SagemakerTrainTaskProps);
    /**
     * The execution role for the Sagemaker training job.
     *
     * Only available after task has been added to a state machine.
     */
    get role(): iam.IRole;
    get grantPrincipal(): iam.IPrincipal;
    /**
     * Add the security group to all instances via the launch configuration
     * security groups array.
     *
     * @param securityGroup: The security group to add
     */
    addSecurityGroup(securityGroup: ec2.ISecurityGroup): void;
    bind(task: sfn.Task): sfn.StepFunctionsTaskConfig;
    private renderParameters;
    private renderAlgorithmSpecification;
    private renderInputDataConfig;
    private renderOutputDataConfig;
    private renderResourceConfig;
    private renderStoppingCondition;
    private renderHyperparameters;
    private renderTags;
    private renderVpcConfig;
    private makePolicyStatements;
}
